@@ -25,10 +25,10 @@ class RiteAidAPI:
         """Refill a prescription."""
         # Using application/x-www-form-urlencoded
         form = "refillPrescriptions={}&location={}&pickUpDate={}&pickUpTime={}&phone={}".format(
-            quote(json.dumps(prescription_nums)),
-            quote(store_id),
-            quote(date),
-            quote(time),
+            quote(json.dumps(prescription_nums)).replace("%20", ""),
+            quote(str(store_id)),
+            quote(date).replace("-", "%\2F"),
+            quote(time).replace("%20", "+"),
             quote(phone),
         )
         async with aiohttp.ClientSession() as session:
